Yandex
------

App registration (get key and secret here)
    https://oauth.yandex.com/client/new

Development callback URL
    https://oauth.yandex.com/verification_code

Yandex OAuth app has many different access rights for its services. For the basic access level,
you just need to a choose "Yandex.Passport API" section and check "Access to email address" and
"Access to username, first name and surname, gender". Everything else is optional.
